@@ -5,6 +5,7 @@ use warnings;
 
 use parent 'OAuth::Lite2::Server::GrantHandler';
 use OAuth::Lite2::Server::Error;
+use OAuth::Lite2::ParamMethod::AuthHeader;
 use Carp ();
 
 sub handle_request {
@@ -12,7 +13,9 @@ sub handle_request {
 
     my $req = $dh->request;
 
-    my $client_id = $req->param("client_id");
+    my $parser = OAuth::Lite2::ParamMethod::AuthHeader->new;
+    my $header_credentials = $parser->basic_credentials($req);
+    my $client_id = ($header_credentials->{client_id}) ? $header_credentials->{client_id} : $req->param("client_id");
 
     my $code = $req->param("code")
         or OAuth::Lite2::Server::Error::InvalidRequest->throw(
@@ -24,6 +27,8 @@ sub handle_request {
             description => "'redirect_uri' not found"
         );
 
+    my $server_state = $req->param("server_state");
+
     my $auth_info = $dh->get_auth_info_by_code($code)
         or OAuth::Lite2::Server::Error::InvalidGrant->throw;
 
@@ -38,6 +43,13 @@ sub handle_request {
         unless ( $auth_info->redirect_uri
             && $auth_info->redirect_uri eq $redirect_uri);
 
+    if ( $auth_info->server_state ) {
+        OAuth::Lite2::Server::Error::InvalidServerState->throw
+            unless ( $server_state and $server_state eq $auth_info->server_state );
+    } else {
+        OAuth::Lite2::Server::Error::InvalidServerState->throw if ( $server_state );
+    }
+
     my $access_token = $dh->create_or_update_access_token(
         auth_info => $auth_info,
     );
@@ -81,6 +93,8 @@ See L<OAuth::Lite2::Server::GrantHandler> document.
 
 =head1 AUTHOR
 
+Ryo Ito, E<lt>ritou.06@gmail.comE<gt>
+
 Lyo Kato, E<lt>lyo.kato@gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
