@@ -7,6 +7,8 @@ use OAuth::Lite2::Server::GrantHandler::AuthorizationCode;
 use OAuth::Lite2::Server::GrantHandler::Password;
 use OAuth::Lite2::Server::GrantHandler::RefreshToken;
 use OAuth::Lite2::Server::GrantHandler::ClientCredentials;
+use OAuth::Lite2::Server::GrantHandler::GroupingRefreshToken;
+use OAuth::Lite2::Server::GrantHandler::ServerState;
 
 my %HANDLERS;
 
@@ -23,6 +25,10 @@ __PACKAGE__->add_handler( 'refresh_token' =>
     OAuth::Lite2::Server::GrantHandler::RefreshToken->new );
 __PACKAGE__->add_handler( 'client_credentials' =>
     OAuth::Lite2::Server::GrantHandler::ClientCredentials->new );
+__PACKAGE__->add_handler( 'grouping_refresh_token' =>
+    OAuth::Lite2::Server::GrantHandler::GroupingRefreshToken->new );
+__PACKAGE__->add_handler( 'server_state' =>
+    OAuth::Lite2::Server::GrantHandler::ServerState->new );
 
 #__PACKAGE__->add_handler( 'assertion' => );
 #__PACKAGE__->add_handler( 'none' => );
@@ -49,8 +55,12 @@ store of handlers for each grant_type.
 
 =head2 add_handler( $grant_type, $handler )
 
+add GrantHandler instance
+
 =head2 get_handler( $grant_type )
 
+get GrantHandler instance
+
 =head1 SEE ALSO
 
 L<OAuth::Lite2::Server::GrantHandler>
@@ -58,9 +68,13 @@ L<OAuth::Lite2::Server::GrantHandler::AuthorizationCode>
 L<OAuth::Lite2::Server::GrantHandler::ClientCredentials>
 L<OAuth::Lite2::Server::GrantHandler::Password>
 L<OAuth::Lite2::Server::GrantHandler::RefreshToken>
+L<OAuth::Lite2::Server::GrantHandler::GroupingRefreshToken>
+L<OAuth::Lite2::Server::GrantHandler::ServerState>
 
 =head1 AUTHOR
 
+Ryo Ito, E<lt>ritou.06@gmail.comE<gt>
+
 Lyo Kato, E<lt>lyo.kato@gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
